"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveFederationConfig = exports.getFederatedPkgName = void 0;
const tslib_1 = require("tslib");
const change_case_1 = require("change-case");
const npm_1 = require("./npm");
const getFederatedPkgName = (pkgName = '') => (0, change_case_1.camelCase)(pkgName.split('/').pop());
exports.getFederatedPkgName = getFederatedPkgName;
const getRemoteEntry = (name, port, host = 'localhost') => `${name}@http://${host}:${port}/remoteEntry.js`;
const resolveFederatedRemotes = (...args_1) => tslib_1.__awaiter(void 0, [...args_1], void 0, function* (packages = []) {
    const packageJSONFiles = yield (0, npm_1.loadPackageJSONFiles)(packages);
    return (yield Promise.all(packageJSONFiles)).reduce((acc, packageJSON) => {
        var _a;
        const name = (0, exports.getFederatedPkgName)(packageJSON.name);
        const port = (_a = packageJSON.config) === null || _a === void 0 ? void 0 : _a.PORT;
        acc[name] = getRemoteEntry(name, port);
        return acc;
    }, {});
});
const resolveSharedRemotes = (packages = [], packageJSON) => packages.reduce((acc, p) => {
    acc[p] = {
        singleton: true,
        requiredVersion: packageJSON.dependencies[p],
    };
    return acc;
}, {});
const resolveFederationConfig = (...args_2) => tslib_1.__awaiter(void 0, [...args_2], void 0, function* (federation = { remotes: [], shared: [] }, packageJSON) {
    const remotes = yield resolveFederatedRemotes(federation.remotes);
    const shared = resolveSharedRemotes(federation.shared, packageJSON);
    return Object.assign(Object.assign({}, federation), { remotes,
        shared });
});
exports.resolveFederationConfig = resolveFederationConfig;
